﻿using System;

using UIKit;
using Infragistics;
using System.Collections.Generic;

namespace GridPullDownOverrideCS
{
	public class GridHelper : IGGridViewDataSourceHelper
	{
		public override IGGridViewPullDownCell CreatePullDownCell (IGGridView gridView)
		{
			IGGridViewPullDownCell cell = gridView.DequeueReusableCell ("PULLDOWN") as IGGridViewPullDownCell;
			if (cell == null) 
			{
				cell = new IGGridViewPullDownCell ("PULLDOWN");
				cell.PullDownText = @"Pull Down to Refresh...";
				cell.ReleaseText = @"Release to Refresh...";
				cell.UpdatingText = @"Updating Data...";
			}
			return cell;
		}
	}

	public partial class ViewController : UIViewController, IIGGridViewDelegate
	{
		IGGridView _gridView;
		GridHelper _dsh;

		public ViewController (IntPtr handle) : base (handle)
		{
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			this.View.BackgroundColor = UIColor.White;

			List<IGSalesmanItem> data = IGSalesmanItem.GenerateData (100);

			_gridView = new IGGridView (this.View.Bounds, IGGridViewStyle.IGGridViewStyleDefault);
			_gridView.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;
			_gridView.BackgroundColor = UIColor.LightGray;
			_gridView.RowBackgroundColor = UIColor.White;

			//Hide the header
			_gridView.HeaderHeight = 0;

			_gridView.WeakDelegate = this; // We must have the delegate set and implement -(void)updateRequestedInGridView:(IGGridView *)gridView for pull down to reload to work.
			this.View.Add(_gridView);

			GridHelper ds = new GridHelper ();
			IGGridViewImageColumnDefinition col = new IGGridViewImageColumnDefinition ("image", IGGridViewImageColumnDefinitionPropertyType.IGGridViewImageColumnDefinitionPropertyTypeImage);
			ds.ColumnDefinitions.Add (col);

			ds.Data = data.ToArray ();

			_dsh = ds;
			_gridView.DataSource = ds;
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
		}

		[Foundation.Export("ReloadData")]
		public void ReloadData()
		{
			List<IGSalesmanItem> data = IGSalesmanItem.GenerateData (100);
			GridHelper ds = (GridHelper)_gridView.DataSource;
			ds.Data = data.ToArray ();
			_gridView.ReloadData ();
			_gridView.FinishedUpdating ();
		}

		[Foundation.Export ("updateRequestedInGridView:")]
		public void UpdateRequested (Infragistics.IGGridView gridView)
		{
			this.PerformSelector(new ObjCRuntime.Selector("ReloadData"), null, 2.5f);
		}
	}
}

